@@ -54,6 +54,8 @@ def disclosure_dataframe(
 ) -> "pd.DataFrame":
     """Disclosures/Footnotes in a DataFrame
 
+    formerly know as "document_dataframe"
+
     :param company_identifiers: list of tickers or CIK codes
     :param disclosure_names: The sections to retrieve, see the full list @ https://www.calcbench.com/disclosure_list.  You cannot request XBRL and non-XBRL sections in the same request.  eg.  ['Management's Discussion And Analysis', 'Risk Factors']
     :param all_history: Search all time periods
@@ -263,7 +265,9 @@ class DislcosureSearchResults(dict):
     network_id: int
     ticker: str
     filing_type: int
+    # Human readable disclosure name as reported by the filer, "Related Party Transactions", "Subsequent Events"
     description: str
+    # The name passed to the API, not set for 8-Ks, assigned by Calcbench.  We try to assign each disclosure to a category.
     disclosure_type_name: str
     period_end_date: str
     footnote_type_title: FootnoteTypeTitle
@@ -343,6 +347,8 @@ def disclosure_search(
 
     Search for footnotes and other sections of 10-K, see https://www.calcbench.com/footnote.
 
+    Formerly know as "document_search"
+
     :param company_identifiers: list of tickers or CIK codes
     :param year: Year to get data for
     :param period: period of data to get.  0 for annual data, 1, 2, 3, 4 for quarterly data.
