@@ -15,6 +15,7 @@ else:
 from calcbench.api_client import (
     CompanyIdentifierScheme,
     CompanyIdentifiers,
+    Period,
     PeriodArgument,
     PeriodType,
     _json_POST,
@@ -51,9 +52,9 @@ class StandardizedPoint(TypedDict):
     metric: str
     value: Union[str, float, int]
     calendar_year: int
-    calendar_period: int
+    calendar_period: Period
     fiscal_year: int
-    fiscal_period: int
+    fiscal_period: Period
     trace_facts: Sequence[TraceData]
     ticker: str
     calcbench_entity_id: int
@@ -85,6 +86,7 @@ def standardized_raw(
     all_face: bool = False,
     all_footnotes: bool = False,
     include_xbrl: bool = False,
+    exclude_errors: bool = True,
 ) -> Sequence[StandardizedPoint]:
     """Standardized data.
 
@@ -102,6 +104,7 @@ def standardized_raw(
     :param year: Get data for a single year, defaults to annual data.
     :param period_type: Either "annual" or "quarterly"
     :param include_preliminary: Include data from non-XBRL 8-Ks and press releases.
+    :param exclude_errors: Run another level of error detections, only works for PIT preliminary
     :return: A list of dictionaries with keys ['ticker', 'calendar_year', 'calendar_period', 'metric', 'value'].
 
     """
@@ -226,6 +229,7 @@ def standardized_raw(
             "periodType": period_type,
             "useFiscalPeriod": use_fiscal_period,
             "accessionID": accession_id,
+            "excludeErrors": exclude_errors,
         },
         "companiesParameters": {
             "entireUniverse": entire_universe,
@@ -253,6 +257,8 @@ def point_in_time(
     include_xbrl: bool = True,
     accession_id: int = None,
     include_trace: bool = False,
+    set_index: bool = False,
+    exclude_errors: bool = False,
 ) -> "pd.DataFrame":
     """Point-in-Time Data
 
@@ -265,6 +271,8 @@ def point_in_time(
     :param include_preliminary: Include facts from non-XBRL earnings press-releases and 8-Ks.
     :param include_xbrl: Include facts from XBRL 10-K/Qs.
     :param include_trace: Include a URL that points to the source document.
+    :param set_index: Set a useful index on the returned DataFrame
+    :param exclude_errors:  Run the error detection
     :return: DataFrame of facts
 
     Columns:
@@ -330,12 +338,38 @@ def point_in_time(
         accession_id=accession_id,
         include_trace=include_trace,
         include_xbrl=include_xbrl,
+        exclude_errors=exclude_errors,
     )
 
     if not data:
         return pd.DataFrame()
 
     data = pd.DataFrame(data)
+
+    # specify the order but include all columns
+    ordered_columns = [
+        "ticker",
+        "metric",
+        "fiscal_year",
+        "fiscal_period",
+        "revision_number",
+        "value",
+        "preliminary",
+        "XBRL",
+        "date_reported",
+        "filing_type",
+        "CIK",
+        "calcbench_entity_id",
+        "period_start",
+        "period_end",
+        "calendar_year",
+        "calendar_period",
+        "filing_accession_number",
+        "trace_url",
+    ]
+
+    new_columns = list(set(data.columns) - set(ordered_columns))
+    data = data.reindex(columns=ordered_columns + new_columns)
     data = data.drop(columns=["trace_facts"], errors="ignore")  # type: ignore
     sort_columns = ["ticker", "metric"]
 
@@ -350,8 +384,26 @@ def point_in_time(
         for date_column in ["date_reported", "period_end", "period_start"]:
             if date_column in data.columns:
                 data[date_column] = pd.to_datetime(data[date_column], errors="coerce")  # type: ignore
-
-    return data.sort_values(sort_columns).reset_index(drop=True)
+    if set_index:
+        if not period_type:
+            data["period"] = (
+                data.fiscal_year.astype(str) + "-" + data.fiscal_period.astype(str)
+            )
+        else:
+            if period_type == PeriodType.Quarterly:
+                data = data[
+                    data.fiscal_period != 0
+                ]  # Sometime annual data gets into the quarterly stream
+                data["period"] = pd.PeriodIndex(
+                    year=data.fiscal_year, quarter=data.fiscal_period, freq="Q"
+                )
+            elif period_type == PeriodType.Annual:
+                data["period"] = data["fiscal_year"]
+        data.drop(["fiscal_year", "fiscal_period"], axis=1, inplace=True)
+        data = data.set_index(["ticker", "metric", "period", "revision_number"])
+    else:
+        data = data.sort_values(sort_columns).reset_index(drop=True)
+    return data
 
 
 def standardized_data(
@@ -484,7 +536,9 @@ def standardized_data(
     return data
 
 
-def _build_quarter_period(data_point, use_fiscal_period):
+def _build_quarter_period(
+    data_point: StandardizedPoint, use_fiscal_period: bool
+) -> "pd.Period":
     try:
         return pd.Period(  # type: ignore
             year=data_point.pop(
@@ -500,7 +554,9 @@ def _build_quarter_period(data_point, use_fiscal_period):
         return pd.Period()  # type: ignore
 
 
-def _build_annual_period(data_point: StandardizedPoint, use_fiscal_period):
+def _build_annual_period(
+    data_point: StandardizedPoint, use_fiscal_period: bool
+) -> "pd.Period":
     data_point.pop("fiscal_period" if use_fiscal_period else "calendar_period")
     return pd.Period(  # type: ignore
         year=data_point.pop("fiscal_year" if use_fiscal_period else "calendar_year"),
